@@ -416,9 +416,6 @@ class Game(object):
 
         """
         if self._running:
-            if sge.DEBUG:
-                print("Restarting the game.")
-
             self.sprites = self._start_sprites
             self.background_layers = self._start_background_layers
             self.backgrounds = self._start_backgrounds
@@ -451,8 +448,6 @@ class Game(object):
 
             self.rooms[0].start()
         else:
-            if sge.DEBUG:
-                print("Starting the game.")
             self._running = True
             self._background_changed = True
             self.event_game_start()
@@ -486,7 +481,6 @@ class Game(object):
             self._display_surface = self._window.copy()
 
             self.rooms[0].start()
-            _fps_time = 0
             self._clock.tick()
 
             while self._running:
@@ -639,13 +633,6 @@ class Game(object):
                     time_passed = 1000 / self.fps
                     delta_mult = 1
 
-                if sge.DEBUG:
-                    _fps_time += real_time_passed
-                    if _fps_time >= 250:
-                        _fps_time = 0
-                        self.window_text = "FPS: {}; Delta: {}".format(
-                            int(1000 / real_time_passed), delta_mult)
-
                 # Alarms
                 activated_alarms = []
                 for a in self._alarms:
@@ -728,8 +715,6 @@ class Game(object):
             self.event_game_end()
             pygame.quit()
             sge.game = None
-            if sge.DEBUG:
-                print("Game ended normally.")
 
     def end(self):
         """Properly end the game."""
@@ -974,32 +959,20 @@ class Game(object):
                 if event.gain:
                     if 2 & event.state:
                         # Gain keyboard focus
-                        if sge.DEBUG:
-                            print('Gained keyboard focus.')
                         self.input_events.append(sge.input.KeyboardFocusGain())
                     if 1 & event.state:
                         # Gain mouse focus
-                        if sge.DEBUG:
-                            print('Gained mouse focus.')
                         self.input_events.append(sge.input.KeyboardFocusLose())
                 else:
                     if 2 & event.state:
                         # Lose keyboard focus
-                        if sge.DEBUG:
-                            print('Lost keyboard focus.')
                         self.input_events.append(sge.input.MouseFocusGain())
                     if 1 & event.state:
                         # Lose mouse focus
-                        if sge.DEBUG:
-                            print('Lost mouse focus.')
                         self.input_events.append(sge.input.MouseFocusLose())
             elif event.type == pygame.QUIT:
-                if sge.DEBUG:
-                    print('Quit requested by the system.')
                 self.input_events.append(sge.input.QuitRequest())
             elif event.type == pygame.VIDEORESIZE:
-                if sge.DEBUG:
-                    print('Video resize detected.')
                 self._window.blit(self._display_surface, (0, 0))
                 self._window_width = event.w
                 self._window_height = event.h
@@ -1321,6 +1294,15 @@ class Game(object):
         """
         sprite = self._get_text_sprite(font, text, width, height, color,
                                        halign, valign, anti_alias)
+        if halign == sge.ALIGN_RIGHT:
+            x -= sprite.width
+        elif halign == sge.ALIGN_CENTER:
+            x -= sprite.width / 2
+        if valign == sge.ALIGN_BOTTOM:
+            y -= sprite.height
+        elif valign == sge.ALIGN_MIDDLE:
+            y -= sprite.height / 2
+
         self.project_sprite(sprite, 0, x, y)
 
     def event_game_start(self):
@@ -1477,10 +1459,7 @@ class Game(object):
         for more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_loose_keyboard_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_gain_mouse_focus(self):
         """Gain mouse focus event.
@@ -1498,10 +1477,7 @@ class Game(object):
         more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_loose_mouse_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_close(self):
         """Close event.
@@ -1672,10 +1648,7 @@ class Game(object):
         for more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_paused_loose_keyboard_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_paused_gain_mouse_focus(self):
         """Gain mouse focus event when paused.
@@ -1693,10 +1666,7 @@ class Game(object):
         more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_paused_loose_mouse_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_paused_close(self):
         """Close event when paused.
