@@ -718,10 +718,7 @@ class Room(object):
         for more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_loose_keyboard_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_gain_mouse_focus(self):
         """Gain mouse focus event.
@@ -739,10 +736,7 @@ class Room(object):
         more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_loose_mouse_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_close(self):
         """Close event.
@@ -862,10 +856,7 @@ class Room(object):
         for more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_paused_loose_keyboard_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_paused_gain_mouse_focus(self):
         """Gain mouse focus event when paused.
@@ -883,10 +874,7 @@ class Room(object):
         more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_paused_loose_mouse_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_paused_close(self):
         """Close event when paused.
